package ru.ibs.framework.pages;

import org.openqa.selenium.*;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.WebDriverWait;

import java.time.Duration;

public class CatalogPage {
    private final WebDriver driver;
    private final WebDriverWait wait;

    public CatalogPage(WebDriver driver) {
        this.driver = driver;
        this.wait = new WebDriverWait(driver, Duration.ofSeconds(10));
    }

    public void selectCategory(String name) {
        WebElement categoryLink = wait.until(ExpectedConditions.elementToBeClickable(
                By.xpath("//a[text()='" + name + "']")));
        categoryLink.click();
    }

    public void selectCategoryMainMenu(String name) {
        WebElement categoryLink = wait.until(ExpectedConditions.elementToBeClickable(
                By.xpath("//a/div[text()='" + name + "']")));
        categoryLink.click();
    }

    public void closeCookieBannerIfPresent() {
        try {
            WebDriverWait wait = new WebDriverWait(driver, Duration.ofSeconds(5));
            WebElement acceptButton = wait.until(ExpectedConditions.elementToBeClickable(
                    By.cssSelector("button.CookieBannerPopover_acceptBtn__VRuFj")));
            acceptButton.click();
            Thread.sleep(500);
        } catch (TimeoutException | InterruptedException e) {

        }
    }

    public void selectSubCategory(String name) {
        closeCookieBannerIfPresent();  // Закрыть баннер если есть

        WebElement subCategory = wait.until(ExpectedConditions.presenceOfElementLocated(
                By.xpath("//p[contains(text(), '" + name + "')]/ancestor::a[1]")));
        // Клик через JS:
        ((JavascriptExecutor) driver).executeScript("arguments[0].scrollIntoView(true);", subCategory);
        ((JavascriptExecutor) driver).executeScript("arguments[0].click();", subCategory);

        // Ждём загрузки фильтра, чтобы убедиться, что перешли
        wait.until(ExpectedConditions.visibilityOfElementLocated(By.cssSelector("input[name='min']")));
    }

}