package ru.ibs.framework.pages;

import org.openqa.selenium.*;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.WebDriverWait;

import java.time.Duration;
import java.util.List;

public class ListingPage {
    private final WebDriver driver;
    private final WebDriverWait wait;

    public ListingPage(WebDriver driver) {
        this.driver = driver;
        this.wait = new WebDriverWait(driver, Duration.ofSeconds(10));
    }

    public void setMinPrice(String price) {
        WebElement minPrice = driver.findElement(By.cssSelector("input[name='min']"));
        minPrice.clear();
        minPrice.sendKeys(price);
        minPrice.sendKeys(Keys.ENTER);
        waitForJSIdle();
    }

    public List<WebElement> getAllProducts() {
        return driver.findElements(By.cssSelector("div.Card_wrap__hES44"));
    }

    public String getFirstProductTitle() {
        return wait.until(ExpectedConditions.visibilityOfElementLocated(
                By.cssSelector("a.CardText_link__C_fPZ > div.CardText_title__7bSbO"))).getText();
    }

    public void waitForJSIdle() {
        new WebDriverWait(driver, Duration.ofSeconds(10)).until(driver ->
                ((JavascriptExecutor) driver).executeScript("return document.readyState").equals("complete")
        );
    }

    public void selectManufacturer(String name) {

        WebElement checkbox = wait.until(ExpectedConditions.elementToBeClickable(
                By.cssSelector("input[id*='" + name + "'] + label")));
        checkbox.click();
        waitForJSIdle();
    }

    public void waitForSearchResultsToUpdate(int expectedCount) {
        wait.until(driver -> getAllProducts().size() <= expectedCount);
        waitForJSIdle(); // если хочешь ещё чуть-чуть гарантии
    }
}
